﻿using System;
using System.Windows;
using System.Windows.Controls;
using CustomCropTool;
using Telerik.Windows.Controls;
using Telerik.Windows.Media.Imaging.Commands;
using Telerik.Windows.Media.Imaging.Tools.UI;

namespace Telerik.Windows.Media.Imaging.Tools
{
    public class FixedRatioCropTool : ITool
    {
        private RadImageEditor imageEditor;
        private FixedRatioCropAdorner cropAdorner;
        private Panel previewPanel;
        private bool isDirty;

        public bool IsPreviewOverlay { get { return true; } }
        public bool AffectsLayout { get { return false; } }


        public FixedRatioCropTool()
        {
            this.cropAdorner = new FixedRatioCropAdorner();
        }

        public IImageCommand GetCommand()
        {
            return new FixedRationCropCommand();
        }

        public object GetContext()
        {
            return new CropCommandContext(
                (int)Math.Round(this.cropAdorner.CropRect.X),
                (int)Math.Round(this.cropAdorner.CropRect.Y),
                (int)Math.Round(this.cropAdorner.CropRect.Width),
                (int)Math.Round(this.cropAdorner.CropRect.Height)
            );
        }

        public UIElement GetSettingsUI()
        {
            return null;
        }

        public void ResetSettings()
        {
            this.cropAdorner.CropRect = new Rect( //0, 0, this.imageEditor.Image.Width, this.imageEditor.Image.Height);
                this.imageEditor.Image.Width * 0.1,
                this.imageEditor.Image.Height * 0.1,
                this.imageEditor.Image.Width * 0.8,
                this.imageEditor.Image.Height * 0.8
            );

            this.isDirty = false;
        }

        public void AttachUI(ToolInitInfo previewInitInfo)
        {
            this.previewPanel = previewInitInfo.PreviewPanel;
            this.imageEditor = previewInitInfo.ImageEditor;

            this.cropAdorner.ImageEditor = this.imageEditor;
            StyleManager.SetThemeFromParent(this.cropAdorner, this.imageEditor);

            this.ResetSettings();

            this.cropAdorner.CropRectChanged += this.cropAdorner_CropRectChanged;

            this.cropAdorner.AssureHasNoParent();
            this.previewPanel.Children.Add(this.cropAdorner);
        }

        void cropAdorner_CropRectChanged(object sender, EventArgs e)
        {
            this.isDirty = true;
        }

        public void DetachUI()
        {
            this.cropAdorner.CropRectChanged -= this.cropAdorner_CropRectChanged;
            this.imageEditor = null;

            this.previewPanel.Children.Clear();
            this.previewPanel = null;
        }

        public bool IsDirty
        {
            get { return this.isDirty; }
        }
    }
}
